<?php

/**
*
* Trackback Manager Class for MODx 0.9.5
*
*  Author  : soushi
*  Version : 1.04
*  Date    : 2007/10/10
*
*  License : GPL
*
*/

require_once('tbconfig.php');
require_once('tbtemplate.php');

class TrackbackMng{

  var $Charset;           // Charset
  var $Theme;             // CSS Theme
  var $TopURI;            // Top URI
  var $Cnf;               // Config data Class
  var $TP;                // Template Class
  var $LogLevel;          // Log Level

  var $TbPageMax = 5;     // Page List Max(x2)

  //opcode
  var $OP_DEFAULT     = 'default';  //default mode
  var $OP_TBLIST      = 'tblist';   //trackback list mode
  var $OP_TBEDIT      = 'tbedit';   //trackback edit mode
  var $OP_TBDETAIL    = 'tbdetail'; //trackback detail mode
  var $OP_CONFIG      = 'config';   //config mode
  var $OP_SAVECONFIG  = 'saveconfig';  //save config mode
  var $OP_DBCREATE    = 'dbcreate';  //save config mode
  var $OP_DROPNEW     = 'dropnew';  //new flag drop

  //-----------------------------------------------------
  // Class Constructure
  // 
  // $fCharset  : string : text charset
  // $fChunk    : string : Chunk name
  // $fLogLevel : intger : Log level
  // return : none
  //-----------------------------------------------------
  function TrackbackMng($fCharset = "UTF-8",$fChunk='',$fLogLevel=''){
    global $modx;

    $this->Cnf      = new TrackbackConfig($fChunk,$fLogLevel);
    $this->TP       = new TrackbackTemplate();
    $this->LogLevel = $fLogLevel == '' ? $this->Cnf->L_ERROR : $fLogLevel;
    $this->Charset  = $fCharset;
    $this->TopURI   = $_SERVER["REQUEST_URI"];

  } 

  //-----------------------------------------------------
  //  Main routine
  //
  // $fOpcode : string : operation code
  //  return  : string : result HTML
  //-----------------------------------------------------
  function Action($fOpcode){
    global $_lang;

    $output = '';
    $info = '';
    $err  = '';
    switch($fOpcode) {
    case $this->OP_TBEDIT: // edit mode
      if( $this->EditTbList() ){
	$info = $_lang['tbm_tbedit_ok'];
      }else{
	$err = $_lang['tbm_tbedit_ok'];
      }

    case $this->OP_TBLIST: // list mode
      $output = $this->ShowTbList($info,$err);
      $output = $this->TP->Show('header') . $output . $this->TP->Show('footer');
      break;

    case $this->OP_TBDETAIL: // detail mode
      $output = $this->TP->Show('header') .
	$this->ShowTbDetail().
	$this->TP->Show('footer');
      break;

    case $this->OP_CONFIG: // config mode
      $output = $this->TP->Show('header') .
	$this->ShowConfig().
	$this->TP->Show('footer');
      break;

    case $this->OP_SAVECONFIG: // saveconfig mode
      if( $this->Cnf->SetConfigFromPost()){
	if( $this->Cnf->SaveConfigToChunk()){
	  $output .= $this->ShowMenu();
	}else{
	  $output .= 'fail!';
	}
	$output = $this->TP->Show('header') . $output .$this->TP->Show('footer');
		
      }else{
      $output = $this->TP->Show('header') .
	$this->ShowConfig('',$this->Cnf->ErrMsg).
	$this->TP->Show('footer');
      }
      break;

    case $this->OP_DBCREATE: // database initialisation
      if( $this->Cnf->DBInit() ){
	$msg= $_lang['tbm_tb_create_ok'];
      }else{
	$msg= $this->Cnf->ErrMsg;
      }
      $output = $this->ShowMenu($msg);
      $output = $this->TP->Show('header') . $output . $this->TP->Show('footer');
      break;
	
    case $this->OP_DROPNEW: // Drop new flag
      if( $this->DropNewFlag($_POST['DropID'])){
	$output = $_POST['DropID'];
      }else{
	$output = '-1';
      }
      break;
    default: // display manu page
      $output = $this->ShowMenu($msg);
      $output = $this->TP->Show('header') . $output . $this->TP->Show('footer');
      break;
      
    }

    return $output;
  }

  //-----------------------------------------------------
  //  Set theme
  //
  // $fTheme : string : css theme path
  //  return : none
  //-----------------------------------------------------
  function SetTheme($fTheme){
    $this->TP->AddPlaceholder('Theme','media/style'.$fTheme);
    $this->Theme = $fTheme; //-> erase
  }

  //-----------------------------------------------------
  //  Show Menu
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowMenu($fInfoMsg='',$fErrMsg=''){
    //global $modx;

    $this->TP->AddPlaceholder('Javascript',$this->TP->Show('menu_js'));
    
    $ph= array();
    $ph['InfoMsg'] =$this->MakeInfo($fInfoMsg,'info');
    $ph['ErrMsg'] =$this->MakeInfo($fErrMsg,'err');
    return $this->TP->Show('menu',$ph);

  } 

  //-----------------------------------------------------
  //  Edit Trackback Edit
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function EditTbList(){
    global $modx;
    global $_lang;

    //value init
    $dView=array();
    $cView=array();
    $cDele=array();
    if( isset($_POST['DView']) && is_array($_POST['DView'])){
      $dView = $_POST['DView'];
    }
    if( isset($_POST['CheckView']) && is_array($_POST['CheckView'])){
      $cView = $_POST['CheckView'];
    }
    if( isset($_POST['CheckDele']) && is_array($_POST['CheckDele'])){
      $cDele = $_POST['CheckDele'];
    }

    foreach( $cView as $key =>$val ){
      if(! is_numeric($val)){
	unset($cView[$key]);
	continue;
      }
      $key2 = array_search($val,$dView);
      if( $key2 !== false){
	unset($dView[$key2]);
	unset($cView[$key]);
      }
    }
    foreach( $dView as $key =>$val ){
      if(! is_numeric($val)){unset($dView[$key]);}
    }

    //enable view
    $fields = 'status = ' . $this->Cnf->ST_VIEW . ' | status';
    $where = '';
    foreach( $cView as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->update($fields,
				   $this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    //disable view
    $fields = 'status = ~' . $this->Cnf->ST_VIEW . ' & status';
    $where = '';
    foreach( $dView as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->update($fields,
				   $this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    //delete trackback
    $where = '';
    foreach( $cDele as $val){
      $where .= "id= $val or ";
    }
    if( $where != ''){
      $where = substr($where,0,strlen($where) - 3);
      if(! $rs = $modx->db->delete($this->Cnf->Table,
				   $where)){
	return false;
      }
    }

    return true;

  }

  //-----------------------------------------------------
  //  Show Trackback Edit
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowTbList($fInfoMsg='',$fErrMsg=''){
    global $modx;
    global $_lang;

    $infoMsg=$this->MakeInfo($fInfoMsg,'info');
    $errMsg =$this->MakeInfo($fErrMsg,'err');

    // make tblist line
    $tbLineHTML='';
    if( isset($_POST['tbLine'])  && is_numeric($_POST['tbLine']) && $_POST['tbLine'] >= 0 ){
      $tbLine = $_POST['tbLine'];
    }else{
      $tbLine = 20;
    }
    foreach(array(10,20,50,100,0) as $val){
      $tmpSelect = $tbLine ==  $val ? ' selected=" selected"' : '';
      $tmpVal = $val == 0 ? $_lang['tbm_tblist_lineall'] : $val;
      $tbLineHTML .= '<option value="'.$val.'"'.$tmpSelect.'>'.$tmpVal.'</option>' . "\n";
    }
    $tbLineHTML = '<select name="tbLine" class="inputBox" onchange="postForm(\''.$this->OP_TBLIST.'\');">'.
      $tbLineHTML.'</select>';

    //make page list
    if( $tbLine == 0 ){
      $tbPageHTML = '';
      $tbPage = 1;
    }else{
      if( isset($_POST['tbPage'])  && is_numeric($_POST['tbPage']) && $_POST['tbPage'] > 0 ){
	$tbPage = $_POST['tbPage'];
      }else{
	$tbPage = 1;
      }
      if(! $rs = $modx->db->select("count(*) as cnt",
				   $this->Cnf->Table)){
	return $_lang['tbm_fail_query'];
      }
      $row= $modx->db->getRow($rs);
      $cnt=$row['cnt'];
      $tbAllPage = (int)((($cnt - 1)/ $tbLine)+1);
      $tbPage > $tbAllPage && $tbPage = $tbAllPage;
      if( $tbAllPage != 0 ){
	$tbLHTML = '';
	$tbRHTML = '';
	$tbLNum = $tbPage;
	$tbRNum = $tbPage;
	for( $i = 0 ; $i < $this->TbPageMax ; $i++){
	  $tbLNum = $tbLNum - 1;
	  if( $tbLNum >= 1 ){
	    $tbLHTML = '<a href="#" onclick="changeTbPage('.$tbLNum.');postForm(\''.$this->OP_TBLIST.'\');">'.
	      $tbLNum.'</a>'. '&nbsp;'."\n". $tbLHTML ;
	  }
	  $tbRNum = $tbRNum + 1;
	  if( $tbRNum <= $tbAllPage ){
	    $tbRHTML .= '&nbsp;'.
	      '<a href="#" onclick="changeTbPage('.$tbRNum.');postForm(\''.$this->OP_TBLIST.'\');">'.
	      $tbRNum.'</a>'."\n";
	  }
	}
	$tbLNum > 1 && $tbLHTML = '...' . $tbLHTML;
	$tbRNum < $tbAllPage && $tbRHTML .= '...';
	$tbPageHTML = '<div style="text-align:right">'.
	  $tbLHTML.$tbPage."\n".$tbRHTML.
	  '('. $_lang['tbm_tblist_total'] . $cnt.')'.
	  '</div>' . "\n";
      }
    }

    //make tb list(header) and set Sort
    $tbListHead = '';
    if( isset($_POST['tbSort'])  && is_numeric($_POST['tbSort']) && $_POST['tbSort'] > 0 ){
      $tbSort = $_POST['tbSort'];
    }else{
      $tbSort = 4; //4 = create date
    }
    if( isset($_POST['tbDesc']) && $_POST['tbDesc'] == 0){
      $tbDesc = 0;
    }else{
      $tbDesc = 1;
    }
    for( $i=1 ; $i<8 ; $i++){
      $rowText = $_lang['tbm_tblist_row'.$i];
      if( $i != 5 && $i != 7 ){
	if( $i != $tbSort){
	  $rowJS='onclick="changeTbSort('.$i.');postForm(\''.$this->OP_TBLIST.'\');"';
	}else{
	  $rowText .= $_lang['tbm_tblist_desc'.$tbDesc];
	  $rowJS='onclick="changeTbDesc('.$tbDesc.');postForm(\''.$this->OP_TBLIST.'\');"';
	}
      }else{
	$rowJS='';
      }

      $tbListHead .= '<td  class="gridHeader" align="center" style="cursor:pointer;" '.$rowJS.'>'.$rowText.'</a></td>'."\n";
    }
    $tbListHead = '<tr>'.$tbListHead.'</tr>';

    //make tb list
    if( $tbLine != 0 && $tbPage != 0 ){
      $topTb = ($tbPage - 1) * $tbLine;
      $limit = $topTb.','.$tbLine;
    }else{
      $limit = '';
    }
    switch($tbSort){
    case 1:
      $order = 'parent_id';
      break;
    case 2:
      $order = 'title';
      break;
    case 3:
      $order = 'blog_name';
      break;
    case 6:
      $order = 'status';
      break;
    default:
      $order = 'date';
    }
    $desc = $tbDesc == 1 ? 'desc' : '';
    if(! $rs = $modx->db->select("id,parent_id,url,title,blog_name, date,status",
				 $this->Cnf->Table,
				 '',
				 "$order $desc",
				 $limit)){

      return $_lang['tbm_fail_query'];
    }
    $i=0;
    $swapCSS[0] = 'gridItem';
    $swapCSS[1] = 'gridAltItem';
    $tbList = '';
    $tbListHide = '';
    while ($row= $modx->db->getRow($rs)) {

      $date = strftime("%Y/%m/%d %T",$row['date']);
      $row['view'] = ($row['status'] & $this->Cnf->ST_VIEW) > 0 ? true:false;
      $row['new'] = ($row['status'] & $this->Cnf->ST_NEW) > 0 ? true:false;
      if( $row['new'] == true ){
	$tbNew = '<span id="new'.$row['id'].'">'
	  . '(<a href="#" onclick="dropNew('.$row['id'].');">'
	  .$_lang['tbm_tblist_new']
	  .'</a>)'
	  .'</span>';
      }else{
	$tbNew = '';
      }

      if( $row['view'] == true ){
	$tbListHide .= '<input name="DView[]" type="hidden" value="'.$row['id'].'" />' . "\n";
      }

      $tbList .=<<<_
<tr>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="{$modx->makeUrl($row['parent_id'],'','','full')}" target="_blank">
        {$row['parent_id']}
    </a>
    <span style="font-size:90%">{$tbNew}</span>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="{$row['url']}" target="_blank">
	{$row['title']}
    </a>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">{$row['blog_name']}</td>
  <td  class="{$swapCSS[$i]}" align="center">{$date}</td>
  <td  class="{$swapCSS[$i]}" align="center">
    <a href="#" onclick="postFormDetail('{$this->OP_TBDETAIL}',{$row['id']});">
      {$_lang['tbm_tblist_detail']}
    </a>
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    {$this->MakeCheckBox('CheckView[]',$row['id'],$row['view'])}
  </td>
  <td  class="{$swapCSS[$i]}" align="center">
    {$this->MakeCheckBox('CheckDele[]',$row['id'],false)}
  </td>

</tr>

_;
      $i = 1 - $i;
    }
    $tbList == '' && $tbList = '<tr><td colspan="7" class="gridItem" align="center">'.$_lang['tbm_tblist_no_list'].'</td></tr>';

    //make JS
    $ph = array();
    $ph['TopURI'] = $this->TopURI;
    $this->TP->AddPlaceholder('Javascript',$this->TP->Show('tblist_js',$ph));
    //make hidden data
    $tbListHide .= '<input name="tbPage" type="hidden" value="'.$tbPage.'" />'
      . '<input name="tbSort" type="hidden" value="'.$tbSort.'" />'
      . '<input name="tbDesc" type="hidden" value="'.$tbDesc.'" />'
      . '<input name="tbDetail" type="hidden" value="" />';
    $this->TP->AddPlaceholder('hidden_input',$tbListHide);

    //make HTML
    //Page Html
    $output = $tbPageHTML;

    //tblist flame(table tag)
    $ph = array();
    $ph['tblist_body'] = $tbListHead . $tbList;
    $output;
    $output .= $this->TP->Show('tblistflame',$ph);

    //section
    $ph = array();
    $ph['section_title'] = $_lang['tbm_title_tblist'] .'&nbsp;&nbsp;:&nbsp;&nbsp;'. $_lang['tbm_tblist_line'] .$tbLineHTML;
    $ph['section_body'] = $output;
    $output = $this->TP->Show('section',$ph);

    //make update button
    $bph1 = array();
    $bph1['HeadMenuBtnID']   = 'Button1';
    $bph1['HeadMenuBtnClick']= "postFormDelCk('$this->OP_TBEDIT');";
    $bph1['HeadMenuBtnIcon'] = 'save.gif';
    $bph1['HeadMenuBtnName'] = $_lang['tbm_btn_edit'];
    //make cancel button
    $bph2 = array();
    $bph2['HeadMenuBtnID']   = 'Button5';
    $bph2['HeadMenuBtnClick']= "document.location.href='$this->TopURI';";
    $bph2['HeadMenuBtnIcon'] = 'cancel.gif';
    $bph2['HeadMenuBtnName'] = $_lang['tbm_btn_cancel'];
    //headmenu
    $ph = array();
    $ph['InfoMsg'] =$this->MakeInfo($fInfoMsg,'info');
    $ph['ErrMsg'] =$this->MakeInfo($fErrMsg,'err');
    $ph['HeadMenuTitle'] =$_lang['tbm_title_top'];
    $ph['HeadMenuList'] = $this->TP->Show('headmenu_btn',$bph1)
     . $this->TP->Show('headmenu_btn',$bph2);
    $output = $this->TP->Show('headmenu',$ph) . $output;

    return $output;

  } 

  //-----------------------------------------------------
  //  Show Trackback Detail
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowTbDetail($fInfoMsg='',$fErrMsg=''){
    global $modx;
    global $_lang;

    if(!( isset($_POST['tbDetail']) && 
	is_numeric($_POST['tbDetail']) &
	  $_POST['tbDetail'] > 0)){
      return $_lang['tbm_detail_no_id'];
    }
    $tbDetail = $_POST['tbDetail'];

    //drop new flag
    if(! $this->DropNewFlag($tbDetail)){
      return $_lang['tbm_fail_query'];
    }

    if(! $rs = $modx->db->select('*',
				 $this->Cnf->Table,
				 "id = $tbDetail")){
      return $_lang['tbm_fail_query'];
    }
    $row= $modx->db->getRow($rs);

    $row['view'] = ($row['status'] & $this->Cnf->ST_VIEW) > 0 ? true:false;
    $row['new'] = ($row['status'] & $this->Cnf->ST_NEW) > 0 ? true:false;
    $excerpt = str_replace("\n","<br />\n",$row['excerpt']);
    $date = strftime("%Y/%m/%d %T",$row['date']);
    $view = $row['view'] == true ? $_lang['tbm_detail_view_ok'] : $_lang['tbm_detail_view_ng'];

    //other hidden data
    if( isset($_POST['tbPage'])  && is_numeric($_POST['tbPage']) && $_POST['tbPage'] >= 0 ){
      $tbPage = $_POST['tbPage'];
    }
    if( isset($_POST['tbSort'])  && is_numeric($_POST['tbSort']) && $_POST['tbSort'] > 0 ){
      $tbSort = $_POST['tbSort'];
    }
    if( isset($_POST['tbDesc']) && $_POST['tbDesc'] == 0){
      $tbDesc = 0;
    }else{
      $tbDesc = 1;
    }
    if( isset($_POST['tbLine'])  && is_numeric($_POST['tbLine']) && $_POST['tbLine'] >= 0 ){
      $tbLine = $_POST['tbLine'];
    }

    // make hidden data
    $hidden =  '<input name="tbPage" type="hidden" value="'.$tbPage.'" />'
      . '<input name="tbSort" type="hidden" value="'.$tbSort.'" />'
      . '<input name="tbDesc" type="hidden" value="'.$tbDesc.'" />'
      . '<input name="tbLine" type="hidden" value="'.$tbLine.'" />';
    $this->TP->AddPlaceholder('hidden_input',$hidden);

    // make HTML
    $output = '';
    $ph = array();
    $i=1;
    while(isset($_lang['tbm_detail_'.$i])){
      $ph['tbdetail_name'] = $_lang['tbm_detail_'.$i];
      switch($i){
      case 1:
	$body = '<a href="'.$modx->makeUrl($row['parent_id'],'','','full').'" target="_blank">'
	  .$row['parent_id'].'</a>';
	break;
      case 2:
	$body = '<a href="http://'.$row['domain'].'" target="_blank">'
	  . $row['domain'].'</a>';
	break;
      case 3:
	$body = $row['remoteip'];
	break;
      case 4:
        $body = '<a href="'.$row['url'].'" target="_blank">'
	  . $row['url'] .'</a>';
	break;
      case 5:
        $body = $row['blog_name'];
	break;
      case 6:
        $body = $row['title'];
	break;
      case 7:
        $body = $excerpt;
	break;
      case 8:
        $body = $date;
	break;
      case 9:
        $body = $view;
	break;
      default:
	$body ='Unknown error.';
      }
      $ph['tbdetail_body'] =$body;
      $output .= $this->TP->Show('tbdetail',$ph);
      $i++;
    }

    //tbdetail flame(table tag)
    $ph = array();
    $ph['tbdetail_body'] = $output;
    $output = $this->TP->Show('tbdetailflame',$ph);

    //section
    $ph = array();
    $ph['section_title'] = $_lang['tbm_title_detail'];
    $ph['section_body'] = $output;
    $output = $this->TP->Show('section',$ph);

    //make back button
    $bph1 = array();
    $bph1['HeadMenuBtnID']   = 'Button1';
    $bph1['HeadMenuBtnClick']= "postForm('$this->OP_TBLIST');";
    $bph1['HeadMenuBtnIcon'] = 'cancel.gif';
    $bph1['HeadMenuBtnName'] = $_lang['tbm_btn_back'];
    //headmenu
    $ph = array();
    $ph['InfoMsg'] =$this->MakeInfo($fInfoMsg,'info');
    $ph['ErrMsg'] =$this->MakeInfo($fErrMsg,'err');
    $ph['HeadMenuTitle'] =$_lang['tbm_title_top'];
    $ph['HeadMenuList'] = $this->TP->Show('headmenu_btn',$bph1);
    $output = $this->TP->Show('headmenu',$ph) . $output;

    return $output;

  }

  //-----------------------------------------------------
  //  Show Config
  //
  //  return : string : menu HTML
  //-----------------------------------------------------
  function ShowConfig($fInfoMsg='',$fErrMsg=''){
    //global $modx;
    global $_lang;

    $output = '';
    $ph = array();
    $i=1;
    while(isset($_lang['tbm_conf_'.$i])){
      $ph['config_name'] = $_lang['tbm_conf_'.$i];
      $ph['config_detail'] = $_lang['tbm_conf_'.$i.'d'];
      switch($i){
      case 1:
	$body = $this->MakeRadioYesNo('EnableSendAlert',$this->Cnf->GetValue('EnableSendAlert'));
	break;
      case 2:
	$body = $this->MakeTextbox('SendAlertUser',$this->Cnf->GetValue('SendAlertUser'),30);
	break;
      case 3:
	$body = $this->MakeTextbox('ReceiveDocID',$this->Cnf->GetValue('ReceiveDocID'),3,20);
	break;
      case 4:
        $body = $this->MakeTextbox('DocAuthor',$this->Cnf->GetValue('DocAuthor'),30);
	break;
      case 5:
        $body = $this->MakeRadioYesNo('OverwriteDocAuthor',$this->Cnf->GetValue('OverwriteDocAuthor'));
	break;
      case 6:
        $body = $this->MakeTextbox('AllowDocID_Recv',$this->Cnf->GetValue('AllowDocID_Recv'),30);
	break;
      case 7:
        $body = $this->MakeTextbox('AllowDocID_Send',$this->Cnf->GetValue('AllowDocID_Send'),30);
	break;
      case 8:
        $body = $this->MakeTextbox('AllowDocID_View',$this->Cnf->GetValue('AllowDocID_View'),30);
	break;
      case 9:
        $body = $this->MakeRadioYesNo('EnableNowOpen',$this->Cnf->GetValue('EnableNowOpen'));
	break;
      case 10:
        $body = $this->MakeRadioYesNo('NowOpenExceptOpenDomain',$this->Cnf->GetValue('NowOpenExceptOpenDomain'));
	break;
      case 11:
        $body = $this->MakeTextbox('NowOpenExceptDocID',$this->Cnf->GetValue('NowOpenExceptDocID'),30);
	break;
      case 12:
        $body = $this->MakeRadioYesNo('DenyHideTb',$this->Cnf->GetValue('DenyHideTb'));
	break;
      case 13:
        $body = $this->MakeRadioYesNo('DenyDoubleTb',$this->Cnf->GetValue('DenyDoubleTb'));
	break;
      case 14:
	$body = $this->MakeTextbox('DenyThisTb',$this->Cnf->GetValue('DenyThisTb'),255,100);
	break;
      case 15:
        $body = $this->MakeRadioYesNo('DenyNoMb',$this->Cnf->GetValue('DenyNoMb'));
	break;
      case 16:
        $body = $this->MakeRadioYesNo('CheckOnSendPingFromTV',$this->Cnf->GetValue('CheckOnSendPingFromTV'));
	break;
      case 17:
        $body = $this->MakeRadioYesNo('CheckOnSendPingAutomatic',$this->Cnf->GetValue('CheckOnSendPingAutomatic'));
	break;
      case 18:
        $body = $this->MakeTextbox('ViewTpl',$this->Cnf->GetValue('ViewTpl'),20);
	break;
      case 19:
        $body = $this->MakeTextbox('ViewTplTbList',$this->Cnf->GetValue('ViewTplTbList'),20);
	break;
      case 20:
        $body = $this->MakeTextbox('EmptyText',$this->Cnf->GetValue('EmptyText'),20);
	break;
      case 21:
        $body = $this->MakeRadioYesNo('EnableGET',$this->Cnf->GetValue('EnableGET'));
	break;
      default:
	$body ='Unknown error.';
      }
      $ph['config_body'] =$body;
      $output .= $this->TP->Show('config',$ph);
      $i++;
    }

    //config flame(table tag)
    $ph = array();
    $ph['config_body'] = $output;
    $output = $this->TP->Show('configflame',$ph);

    //section
    $ph = array();
    $ph['section_title'] = $_lang['tbm_title_config'];
    $ph['section_body'] = $output;
    $output = $this->TP->Show('section',$ph);

    //make save button
    $bph1 = array();
    $bph1['HeadMenuBtnID']   = 'Button1';
    $bph1['HeadMenuBtnClick']= "postForm('$this->OP_SAVECONFIG');";
    $bph1['HeadMenuBtnIcon'] = 'save.gif';
    $bph1['HeadMenuBtnName'] = $_lang['tbm_btn_save'];
    //make cancel button
    $bph2 = array();
    $bph2['HeadMenuBtnID']   = 'Button5';
    $bph2['HeadMenuBtnClick']= "document.location.href='$this->TopURI';";
    $bph2['HeadMenuBtnIcon'] = 'cancel.gif';
    $bph2['HeadMenuBtnName'] = $_lang['tbm_btn_cancel'];
    //headmenu
    $ph = array();
    $ph['InfoMsg'] =$this->MakeInfo($fInfoMsg,'info');
    $ph['ErrMsg'] =$this->MakeInfo($fErrMsg,'err');
    $ph['HeadMenuTitle'] =$_lang['tbm_title_top'];
    $ph['HeadMenuList'] = $this->TP->Show('headmenu_btn',$bph1)
      . $this->TP->Show('headmenu_btn',$bph2);
    $output = $this->TP->Show('headmenu',$ph) . $output;

    return $output;

  } 

  //-----------------------------------------------------
  //  Make Information Table
  //
  //  $fMsg  : string : information/error message
  //  $fType : string : Message Type
  //  return : string : menu HTML  *notine* "\n" -> "<br />\n"
  //-----------------------------------------------------
  function MakeInfo($fMsg='',$fType=''){
    global $_lang;

    $output = '';
    if( $fMsg != '' ){
      $ph = array();
      if( $fType == 'info'){
	$ph['section_title'] = $_lang['tbm_title_info'];
      }else{
	$ph['section_title'] = $_lang['tbm_title_error'];
      }
      $ph['section_body'] = str_replace("\n","<br />\n",$fMsg);
      $output = $this->TP->Show('section',$ph);
    }

    return $output;
  }

  //-----------------------------------------------------
  //  Make radio button(Yes/No)
  //
  //  $fName   : string  : HTML tag name
  //  $fStatus : bool    : Default check
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeRadioYesNo($fName,$fStatus){
    global $_lang;

    if( $fStatus == true ){
      $chkYes = ' checked';
      $chkNo  = ' ';
    }else{
      $chkYes = '';
      $chkNo  = ' checked';
    }
    $output =
      '<input type="radio" name="'.$fName.'" value="1"'.$chkYes.'>'.$_lang['yes'].
      '<input type="radio" name="'.$fName.'" value="0"'.$chkNo.'>'.$_lang['no']."\n";

    return $output;
  }

  //-----------------------------------------------------
  //  Make Checkbox(Single)
  //
  //  $fName   : string  : name option
  //  $fVal    : string  : value option
  //  $fStatus : bool    : Default check
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeCheckBox($fName,$fVal,$fStatus){
    global $_lang;

    $chk = $fStatus == true ? ' checked' : '';
    $output = '<input type="checkbox" name="'.$fName.'" value="'.$fVal.'"'.$chk.'>';

    return $output;
  }

  //-----------------------------------------------------
  //  Make Textbox
  //
  //  $fName   : string         : HTML tag name
  //  $fValue  : string/integer : Default data
  //  $fLen    : integer        : Text Length(default:20)
  //  $fSize   : integer        : Text Area Size(default:$fLen)
  //  return   : string : HTML
  //-----------------------------------------------------
  function MakeTextbox($fName,$fValue,$fLen=20,$fSize=0){

    $fLen = is_numeric($fLen) ? $fLen : 20;
    if( $fSize == 0 || ! is_numeric($fSize)){$fSize=$fLen;}

    $output = '<input type="text" name="'.$fName.'" value="'.$fValue.'" size="'.$fSize.'" maxlength="'.$fLen.'"><br />'."\n";

    return $output;
  }

  //-----------------------------------------------------
  //  Drop New Flag
  //
  //  $fId   : integer : ID
  //  return : bool
  //-----------------------------------------------------
  function DropNewFlag($fId){
    global $modx;

    if(! is_numeric($fId) ){return false;}
    if(! $rs = $modx->db->update('status = ~' . $this->Cnf->ST_NEW . ' & status',
				 $this->Cnf->Table,
				 "id = $fId")){
      return false;
    }
    return true;
  }
}
?>
